@@ -24,9 +24,8 @@
 #define SYCK_VERSION    "0.61"
 #define YAML_DOMAIN     "yaml.org,2002"
 
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
+/* Unconditionally added as part of perl's headers anyway: */
+#include <stdlib.h>
 
 #ifdef HAVE_STRING_H
 # include <string.h>
